==> meta_permissions-0.1.0-py3-none-any.whl: meta_permissions/codenames/clinic.py <==
from edc_permissions.codenames import clinic

clinic += [
    "edc_dashboard.view_ae_listboard",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "meta_ae.add_aefollowup",
    "meta_ae.add_aeinitial",
    "meta_ae.change_aefollowup",
    "meta_ae.change_aeinitial",
    "meta_ae.delete_aefollowup",
    "meta_ae.delete_aeinitial",
    "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_prn.add_deathreport",
    "meta_prn.add_onschedule",
    "meta_prn.add_protocoldeviationviolation",
    "meta_prn.add_endofstudy",
    "meta_prn.change_deathreport",
    "meta_prn.change_onschedule",
    "meta_prn.change_protocoldeviationviolation",
    "meta_prn.change_endofstudy",
    "meta_prn.delete_deathreport",
    "meta_prn.delete_onschedule",
    "meta_prn.delete_protocoldeviationviolation",
    "meta_prn.delete_endofstudy",
    "meta_prn.view_deathreport",
    "meta_prn.view_historicaldeathreport",
    "meta_prn.view_historicalonschedule",
    "meta_prn.view_historicalprotocoldeviationviolation",
    "meta_prn.view_historicalendofstudy",
    "meta_prn.view_onschedule",
    "meta_prn.view_protocoldeviationviolation",
    "meta_prn.view_endofstudy",
    "meta_subject.add_subjectrequisition",
    "meta_subject.add_subjectvisit",
    "meta_subject.change_subjectrequisition",
    "meta_subject.change_subjectvisit",
    "meta_subject.delete_subjectrequisition",
    "meta_subject.delete_subjectvisit",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
]
clinic.sort()

==> meta_permissions-0.1.2-py3-none-any.whl: meta_permissions/codenames/clinic.py <==
from edc_permissions.codenames import clinic

clinic += [
    "edc_dashboard.view_ae_listboard",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "meta_ae.add_aefollowup",
    "meta_ae.add_aeinitial",
    "meta_ae.add_deathreport",
    "meta_ae.change_aefollowup",
    "meta_ae.change_aeinitial",
    "meta_ae.change_deathreport",
    "meta_ae.delete_aefollowup",
    "meta_ae.delete_aeinitial",
    "meta_ae.delete_deathreport",
    "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_deathreport",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_ae.view_historicaldeathreport",
    "meta_prn.add_endofstudy",
    "meta_prn.add_onschedule",
    "meta_prn.add_protocoldeviationviolation",
    "meta_prn.change_endofstudy",
    "meta_prn.change_onschedule",
    "meta_prn.change_protocoldeviationviolation",
    "meta_prn.delete_endofstudy",
    "meta_prn.delete_onschedule",
    "meta_prn.delete_protocoldeviationviolation",
    "meta_prn.view_endofstudy",
    "meta_prn.view_historicalendofstudy",
    "meta_prn.view_historicalonschedule",
    "meta_prn.view_historicalprotocoldeviationviolation",
    "meta_prn.view_onschedule",
    "meta_prn.view_protocoldeviationviolation",
    "meta_subject.add_subjectrequisition",
    "meta_subject.add_subjectvisit",
    "meta_subject.change_subjectrequisition",
    "meta_subject.change_subjectvisit",
    "meta_subject.delete_subjectrequisition",
    "meta_subject.delete_subjectvisit",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
]
clinic.sort()
